//#define XERR
#include "analysis.ih"

void Analysis::run()
{
                                // errors may be set at Options or ConfFile
    if (Error::instance().count() != 0)   
        return;                 // construction

    requireBase();              // the base directory must be (made) available

    Loop loop{ d_scenario };

    loop.iterate();
}
